@@ -39,23 +39,22 @@ AUTHORS:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from typing import Optional
-import sage
-import platform
 import os
 import socket
+import subprocess
 import sys
 import sysconfig
-from . import version
-from pathlib import Path
-import subprocess
+from typing import Optional
 
+from platformdirs import site_data_dir, user_data_dir
+
+from sage import version
 
 # All variables set by var() appear in this SAGE_ENV dict
 SAGE_ENV = dict()
 
 
-def join(*args):
+def join(*args) -> str | None:
     """
     Join paths like ``os.path.join`` except that the result is ``None``
     if any of the components is ``None``.
@@ -193,7 +192,7 @@ SAGE_LOCAL_SPKG_INST = var("SAGE_LOCAL_SPKG_INST", join(SAGE_LOCAL, "var", "lib"
 SAGE_SPKG_INST = var("SAGE_SPKG_INST", join(SAGE_LOCAL, "var", "lib", "sage", "installed"))  # deprecated
 
 # source tree of the Sage distribution
-SAGE_ROOT = var("SAGE_ROOT")  # no fallback for SAGE_ROOT
+SAGE_ROOT = var("SAGE_ROOT") or None
 SAGE_SRC = var("SAGE_SRC", join(SAGE_ROOT, "src"), SAGE_LIB)
 SAGE_DOC_SRC = var("SAGE_DOC_SRC", join(SAGE_ROOT, "src", "doc"), SAGE_DOC)
 SAGE_PKGS = var("SAGE_PKGS", join(SAGE_ROOT, "build", "pkgs"))
@@ -205,30 +204,20 @@ SAGE_DOC_SERVER_URL = var("SAGE_DOC_SERVER_URL")
 SAGE_DOC_LOCAL_PORT = var("SAGE_DOC_LOCAL_PORT", "0")
 
 # ~/.sage
-DOT_SAGE = var("DOT_SAGE", join(os.environ.get("HOME"), ".sage"))
+if sys.platform == 'win32':
+    home_dir = os.environ.get("USERPROFILE")
+else:  # Unix-like systems (Linux, macOS, etc.)
+    home_dir = os.environ.get("HOME")
+DOT_SAGE = var("DOT_SAGE", join(home_dir, ".sage"))
 SAGE_STARTUP_FILE = var("SAGE_STARTUP_FILE", join(DOT_SAGE, "init.sage"))
 
 # for sage_setup.setenv
 SAGE_ARCHFLAGS = var("SAGE_ARCHFLAGS", "unset")
 SAGE_PKG_CONFIG_PATH = var("SAGE_PKG_CONFIG_PATH")
 
-try:
-    import sage_wheels
-except ImportError:
-    _sage_wheels_path = []
-else:
-    _sage_wheels_path = sage_wheels.__path__
-
-# colon-separated search path for databases.
-SAGE_DATA_PATH = var("SAGE_DATA_PATH",
-                     os.pathsep.join(filter(None, [
-                             join(DOT_SAGE, "db"),
-                         ] + [
-                             join(p, "share") for p in _sage_wheels_path
-                         ] + [
-                             join(SAGE_SHARE, "sagemath"),
-                             SAGE_SHARE,
-                         ])))
+# colon-separated search path for databases
+# should not be used directly; instead use sage_data_paths
+SAGE_DATA_PATH = var("SAGE_DATA_PATH")
 
 # database directories, the default is to search in SAGE_DATA_PATH
 CREMONA_LARGE_DATA_DIR = var("CREMONA_LARGE_DATA_DIR")
@@ -267,6 +256,12 @@ else:
             ECLDIR = dir + '/'
             os.environ['ECLDIR'] = ECLDIR
             break
+    for p in sage_wheels.__path__:
+        pari_datadir = os.path.join(p, 'share/pari')
+        if any(os.path.exists(os.path.join(pari_datadir, data))
+               for data in ['galdata', 'seadata']):
+            os.environ['GP_DATA_DIR'] = pari_datadir
+            break
 
 try:
     import ecl
@@ -373,6 +368,10 @@ def sage_include_directories(use_sources=False):
         sage: dirs = sage.env.sage_include_directories(use_sources=True)
         sage: any(os.path.isfile(os.path.join(d, file)) for d in dirs)
         True
+
+    ::
+
+        sage: # optional - !meson_editable (no need, see :issue:`39275`)
         sage: dirs = sage.env.sage_include_directories(use_sources=False)
         sage: any(os.path.isfile(os.path.join(d, file)) for d in dirs)
         True
@@ -462,9 +461,10 @@ def cython_aliases(required_modules=None, optional_modules=None):
         ....: ''')
         435
     """
-    import pkgconfig
     import itertools
 
+    import pkgconfig
+
     if required_modules is None:
         required_modules = default_required_modules
 
@@ -473,11 +473,25 @@ def cython_aliases(required_modules=None, optional_modules=None):
 
     aliases = {}
 
+    # uname-specific flags
+    import platform
+    system = platform.system()
+
+    def uname_specific(name, value, alternative):
+        if system == name:
+            return value
+        else:
+            return alternative
+
     for lib, required in itertools.chain(((lib, True) for lib in required_modules),
                                          ((lib, False) for lib in optional_modules)):
         var = lib.upper().replace("-", "") + "_"
         if lib == 'cblas':
             lib = get_cblas_pc_module_name()
+        if system == 'Windows':
+            aliases[var + "CFLAGS"] = aliases[var + "INCDIR"] = aliases[var + "LIBDIR"] = aliases[var + "LIBEXTRA"] = []
+            aliases[var + "LIBRARIES"] = lib
+            continue
         if lib == 'zlib':
             aliases[var + "CFLAGS"] = ""
             try:
@@ -523,18 +537,11 @@ def cython_aliases(required_modules=None, optional_modules=None):
         aliases[var + "LIBEXTRA"] = list(filter(lambda s: not s.startswith(('-l', '-L')), libs.split()))
         aliases[var + "LIBRARIES"] = pc['libraries']
 
-    # uname-specific flags
-    UNAME = os.uname()
-
-    def uname_specific(name, value, alternative):
-        if name in UNAME[0]:
-            return value
-        else:
-            return alternative
-
     aliases["LINUX_NOEXECSTACK"] = uname_specific("Linux", ["-Wl,-z,noexecstack"],
                                                   [])
 
+    aliases["M_LIBRARIES"] = uname_specific("Windows", [], ["m"])
+
     # LinBox needs special care because it actually requires C++11 with
     # GNU extensions: -std=c++11 does not work, you need -std=gnu++11
     # (this is true at least with GCC 7.2.0).
@@ -563,3 +570,42 @@ def cython_aliases(required_modules=None, optional_modules=None):
     aliases["OPENMP_CXXFLAGS"] = OPENMP_CXXFLAGS.split()
 
     return aliases
+
+
+def sage_data_paths(name: str | None) -> set[str]:
+    r"""
+    Search paths for general data files.
+
+    If specified, the subdirectory ``name`` is appended to the
+    directories. Otherwise, the directories are returned as is.
+
+    EXAMPLES::
+
+        sage: from sage.env import sage_data_paths
+        sage: sage_data_paths("cremona")
+        {'.../cremona'}
+    """
+    if not SAGE_DATA_PATH:
+        paths = {
+            join(DOT_SAGE, "db"),
+            join(SAGE_SHARE, "sagemath"),
+            SAGE_SHARE,
+        }
+        try:
+            import sage_wheels
+        except ImportError:
+            _sage_wheels_path = []
+        else:
+            _sage_wheels_path = sage_wheels.__path__
+        for p in _sage_wheels_path:
+            paths.add(join(p, "share"))
+        paths.add(user_data_dir("sagemath"))
+        paths.add(user_data_dir())
+        paths.add(site_data_dir("sagemath"))
+        paths.add(site_data_dir())
+    else:
+        paths = {path for path in SAGE_DATA_PATH.split(os.pathsep)}
+
+    if name is None:
+        return {path for path in paths if path}
+    return {os.path.join(path, name) for path in paths if path}
